require "numru/advanceddcl"

include NumRu::AdvancedDCL

Dev.open("X",true)
Frame.mgn(0.1, 0.1, 0.05, 0.05)

Frame.div("S", 3, 5)
Frame.mgn(0.05, 0.05, 0.05, 0.05)
Frame.rat(1.0, 1.0)
Text.set("charindex", 2)
Text.set("charsize", 0.1)

(1..15).each{|i|
  Frame.new
  Fig.set("window", [0.0, 1.0, 0.0, 1.0])
  Fig.pwwr(1)
  ctxt = "FRAME#{i}"
  Text.vdraw(0.5, 0.5, ctxt)
}

Dev.close
